# python imports
import os

WORKING_DIRECTORY = os.path.dirname(os.path.realpath(__file__))

FILE_NAME = {
    'states': WORKING_DIRECTORY + '/data/states.csv',
    'ut': WORKING_DIRECTORY + '/data/ut.csv'
}
